Robyn - An async Python Framework written in Rust.

Robyn
View Source
Join Discord

# A fast web framework!

An async web server with the runtime written in Rust.

Docs

    from robyn import Robyn

    app = Robyn(__file__)

    @app.get("/")
    async def h(request):
        return "Hello, world!"

    app.start(port=8080)

## Reasons Why People Love Robyn

Simple API
Full Type Support
Truly F(L)OSS
Blazing Fast
Extensible
Async support

###### and much more....

## Sponsors!

Robyn is powered by these amazing people